@@ -4,6 +4,11 @@ from .__about__ import (  # noqa: F401
     __summary__
 )
 
+from ._py_op_items import (  # noqa: F401
+    OPDocumentItem,
+    OPLoginItem
+)
+
 from .pyonepassword import OP  # noqa: F401
 
 from .py_op_exceptions import (  # noqa: F401
