@@ -1,4 +1,5 @@
 import json
+from json import JSONDecodeError
 from os import environ as env
 from ._py_op_items import (
     OPItemFactory,
@@ -6,7 +7,7 @@ from ._py_op_items import (
     OPLoginItem,
 )
 
-from ._py_op_cli import _OPCLIExecute
+from ._py_op_commands import _OPCommandInterface
 from ._py_op_deprecation import deprecated
 from .py_op_exceptions import (
     OPGetItemException,
@@ -14,11 +15,15 @@ from .py_op_exceptions import (
     OPInvalidDocumentException,
     OPCmdFailedException,
     OPSignoutException,
-    OPForgetException
+    OPForgetException,
+    OPGetUserException,
+    OPGetVaultException,
+    OPGetGroupException,
+    OPListEventsException
 )
 
 
-class OP(_OPCLIExecute):
+class OP(_OPCommandInterface):
     """
     Class for logging into and querying a 1Password account via the 'op' cli command.
     """
@@ -51,29 +56,35 @@ class OP(_OPCLIExecute):
             - OPSigninException if 1Password sign-in fails for any reason.
             - OPNotFoundException if the 1Password command can't be found.
         """
-        super().__init__(account_shorthand=account_shorthand,
+        super().__init__(vault=vault,
+                         account_shorthand=account_shorthand,
                          signin_address=signin_address,
                          email_address=email_address,
                          secret_key=secret_key,
                          password=password,
                          logger=logger,
                          op_path=op_path)
-        self.vault = vault
 
-    def get_item(self, item_name_or_uuid, vault=None):
-        vault_argv = []
-        if vault:
-            vault_argv = ["--vault", vault]
-        elif self.vault:
-            vault_argv = ["--vault", self.vault]
-
-        lookup_argv = [self.op_path, "get", "item", item_name_or_uuid]
-        if vault_argv:
-            lookup_argv.extend(vault_argv)
+    def _get_abstract(self, abstract_obj_type: str, abs_name_or_uuid: str, exception_on_err: OPCmdFailedException):
+        lookup_argv = [self.op_path, "get",
+                       abstract_obj_type, abs_name_or_uuid]
 
         try:
             output = self._run(
                 lookup_argv, capture_stdout=True, decode="utf-8")
+        except OPCmdFailedException as ocfe:
+            raise exception_on_err.from_opexception(ocfe) from ocfe
+
+        try:
+            item_dict = json.loads(output)
+        except JSONDecodeError as jdce:
+            raise exception_on_err.from_opexception(jdce) from jdce
+
+        return item_dict
+
+    def get_item(self, item_name_or_uuid, vault=None):
+        try:
+            output = super().get_item(item_name_or_uuid, vault=vault, decode="utf-8")
         except OPCmdFailedException as ocfe:
             raise OPGetItemException.from_opexception(ocfe) from ocfe
 
@@ -81,6 +92,43 @@ class OP(_OPCLIExecute):
         op_item = OPItemFactory.op_item_from_item_dict(item_dict)
         return op_item
 
+    def get_user(self, user_name_or_uuid: str):
+        return self._get_abstract('user', user_name_or_uuid, OPGetUserException)
+
+    def get_vault(self, vault_name_or_uuid: str):
+        return self._get_abstract('vault', vault_name_or_uuid, OPGetVaultException)
+
+    def get_group(self, group_name_or_uuid: str):
+        return self._get_abstract('group', group_name_or_uuid, OPGetGroupException)
+
+    def list_events(self, eventid=None, older=False):
+        """
+        Returns the 100 most recent events by default.
+        The Activity Log is only available for 1Password Business accounts.
+
+        :param eventid: start listing from event with ID eid
+        :param older: list events from before the specified event
+        :return: Raw JSON list of events
+        """
+        event_argv = []
+        if eventid:
+            event_argv = ["--eventid", eventid]
+            if older:
+                event_argv = ["--older", "--eventid", eventid]
+
+        lookup_argv = [self.op_path, "list", "events"]
+        if event_argv:
+            lookup_argv.extend(event_argv)
+
+        try:
+            output = self._run(
+                lookup_argv, capture_stdout=True, decode="utf-8")
+        except OPCmdFailedException as ocfe:
+            raise OPListEventsException.from_opexception(ocfe) from ocfe
+
+        item_dict = json.loads(output)
+        return item_dict
+
     def get_item_password(self, item_name_or_uuid, vault=None):
         item: OPLoginItem
         item = self.get_item(item_name_or_uuid, vault=vault)
@@ -126,18 +174,9 @@ class OP(_OPCLIExecute):
         except AttributeError as ae:
             raise OPInvalidDocumentException(
                 "Item has no 'fileName' attribute") from ae
-        vault_argv = []
-        if vault:
-            vault_argv = ["--vault", vault]
-        elif self.vault:
-            vault_argv = ["--vault", self.vault]
-        get_document_argv = [self.op_path,
-                             "get", "document", document_name_or_uuid]
-        if vault_argv:
-            get_document_argv.extend(vault_argv)
 
         try:
-            document_bytes = self._run(get_document_argv, capture_stdout=True)
+            document_bytes = super().get_document(document_name_or_uuid, vault=vault)
         except OPCmdFailedException as ocfe:
             raise OPGetDocumentException.from_opexception(ocfe) from ocfe
 
@@ -221,10 +260,6 @@ class OP(_OPCLIExecute):
         Returns:
             - Bytes of the specified document
         """
-        lookup_argv = [self.op_path, "get", "document", item_name_or_uuid]
-        try:
-            output = self._run(lookup_argv, capture_stdout=True)
-        except OPCmdFailedException as ocfe:
-            raise OPGetDocumentException.from_opexception(ocfe) from ocfe
+        output = super().get_document(item_name_or_uuid)
 
         return output
